<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link  https://wp1.co
 * @since 1.0.0
 *
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Product_Brands_For_Woocommerce
 * @subpackage Product_Brands_For_Woocommerce/includes
 */
class Product_Brands_For_Woocommerce {


	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since  1.0.0
	 * @var    Product_Brands_For_Woocommerce_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since  1.0.0
	 * @var    string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		if (defined('PRODUCT_BRANDS_FOR_WOOCOMMERCE_VERSION') ) {
			$this->version = PRODUCT_BRANDS_FOR_WOOCOMMERCE_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'product-brands-for-woocommerce';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

		require_once PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_DIR . 'includes/class-product-brands-for-woocommerce-settings.php';

		include_once PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_DIR . 'includes/class-product-brands-for-woocommerce-functions.php';

		include_once PRODUCT_BRANDS_FOR_WOOCOMMERCE_PLUGIN_DIR . 'includes/product-brands-for-woocommerce-export-import.php';
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Product_Brands_For_Woocommerce_Loader. Orchestrates the hooks of the plugin.
	 * - Product_Brands_For_Woocommerce_I18n. Defines internationalization functionality.
	 * - Product_Brands_For_Woocommerce_Admin. Defines all hooks for the admin area.
	 * - Product_Brands_For_Woocommerce_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since  1.0.0
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		include_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-product-brands-for-woocommerce-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		include_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-product-brands-for-woocommerce-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		include_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-product-brands-for-woocommerce-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		include_once plugin_dir_path(dirname(__FILE__)) . 'public/class-product-brands-for-woocommerce-public.php';

		$this->loader = new Product_Brands_For_Woocommerce_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Product_Brands_For_Woocommerce_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since  1.0.0
	 */
	private function set_locale() {

		$plugin_i18n = new Product_Brands_For_Woocommerce_I18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since  1.0.0
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Product_Brands_For_Woocommerce_Admin($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

		$this->loader->add_action('init', $plugin_admin, 'product_brands_for_woocommerce_add_new_image_sizes');
		$this->loader->add_action('init', $plugin_admin, 'product_brands_for_woocommerce_product_taxonomies');
		$this->loader->add_action('product-brand_add_form_fields', $plugin_admin, 'product_brands_for_woocommerce_add_brand_image', 10, 2);
		$this->loader->add_action('created_product-brand', $plugin_admin, 'product_brands_for_woocommerce_save_brand_image', 10, 2);
		$this->loader->add_action('product-brand_edit_form_fields', $plugin_admin, 'product_brands_for_woocommerce_update_brand_image', 10, 2);
		$this->loader->add_action('edited_product-brand', $plugin_admin, 'product_brands_for_woocommerce_updated_brand_image', 10, 2);
		$this->loader->add_action('manage_edit-product-brand_columns', $plugin_admin, 'product_brands_for_woocommerce_add_brand_columns');
		$this->loader->add_action('woocommerce_before_order_itemmeta', $plugin_admin, 'product_brands_for_woocommerce_before_order_itemmeta', 10, 3);
		$this->loader->add_action('manage_product-brand_custom_column', $plugin_admin, 'product_brands_for_woocommerce_add_brand_column_content', 10, 3);
		$this->loader->add_action('wp_update_product', $plugin_admin, 'product_brands_for_woocommerce_regenerate_permalinks_after_product_update', 10, 2);

		$this->loader->add_action('bulk_edit_custom_box', $plugin_admin, 'product_brands_for_woocommerce_bulk_edit_add', 10, 2 );
		$this->loader->add_action('bulk_edit_custom_box', $plugin_admin, 'product_brands_for_woocommerce_quick_edit_add', 10, 2 );
		$this->loader->add_action('quick_edit_custom_box', $plugin_admin, 'product_brands_for_woocommerce_quick_edit_add', 10, 2 );
		$this->loader->add_action('save_post', $plugin_admin, 'product_brands_for_woocommerce_quick_edit_save' );
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'product_brands_for_woocommerce_enqueue_quick_edit_script' );
		$this->loader->add_action('woocommerce_product_bulk_edit_save', $plugin_admin, 'product_brands_for_woocommerce_bulk_edit_save' );
		$this->loader->add_filter( 'plugin_action_links_' . plugin_basename(plugin_dir_path(__DIR__) . $this->plugin_name . '.php'), $plugin_admin, 'product_brands_for_woocommerce_plugin_action_links' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since  1.0.0
	 */
	private function define_public_hooks() {

		$plugin_public = new Product_Brands_For_Woocommerce_Public($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');

		$this->loader->add_action('woocommerce_product_meta_end', $plugin_public, 'product_brands_for_woocommerce_add_brand_info');
		
		$this->loader->add_action('wp_head', $plugin_public, 'product_brands_for_woocommerce_add_noindex_nofollow');

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since 1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since  1.0.0
	 * @return string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since  1.0.0
	 * @return Product_Brands_For_Woocommerce_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since  1.0.0
	 * @return string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
